==> neptune_local_ui-2.1.0.362.jar: com/tandbergtv/neptune/ui/componentmgr/client/tab/component/model/UiComponent.java <==
package com.tandbergtv.neptune.ui.componentmgr.client.tab.component.model;

import com.tandbergtv.neptune.ui.componentmgr.client.tab.component.model.UiComponent;
import com.tandbergtv.neptune.ui.componentmgr.client.tab.component.model.UiComponentKey;
import com.google.gwt.user.client.rpc.IsSerializable;

public class UiComponent implements IsSerializable {
		
	private UiComponentKey key = new UiComponentKey();
	private String name;
	private String baseURL;
	private Long statusId;
	private String status;

	public UiComponent() {
	}
	
	public Long getId() {
		return this.key.getId();
	}

	public void setId(Long id) {
		this.key.setId(id);
	}

	public UiComponentKey getKey() {
		return key;
	}

	public void setKey(UiComponentKey key) {
		if (key == null)
			key = new UiComponentKey();

		this.key = key;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getBaseURL() {
		return baseURL;
	}

	public void setBaseURL(String url) {
		this.baseURL = url;
	}
	
	public Long getStatusId() {
		return statusId;
	}
	
	public void setStatusId(Long statusId) {
		this.statusId = statusId;
	}
	
	public String getStatus() {
		return status;
	}
	
	public void setStatus(String status) {
		this.status = status;
	}

	/*
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		return key.hashCode() + 41;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;

		if (!(obj instanceof UiComponent))
			return false;

		/* Must have the same keys */
		UiComponent other = (UiComponent) obj;
		return key.equals(other.key);
	}
}

==> neptune_local_ui-5.2.0.134.jar: com/tandbergtv/neptune/ui/componentmgr/client/tab/component/model/UiComponent.java <==
package com.tandbergtv.neptune.ui.componentmgr.client.tab.component.model;


import java.util.Date;

import com.tandbergtv.neptune.ui.componentmgr.client.tab.component.model.UiComponent;
import com.tandbergtv.neptune.ui.componentmgr.client.tab.component.model.UiComponentKey;
import com.google.gwt.user.client.rpc.IsSerializable;

public class UiComponent implements IsSerializable {
		
	private UiComponentKey key = new UiComponentKey();
	private String name;
	private String baseURL;
	private Long statusId;
	private String status;
	private Date lastSuccessfulSynchTimestamp;

	public UiComponent() {
	}
	
	public Long getId() {
		return this.key.getId();
	}

	public void setId(Long id) {
		this.key.setId(id);
	}

	public UiComponentKey getKey() {
		return key;
	}

	public void setKey(UiComponentKey key) {
		if (key == null)
			key = new UiComponentKey();

		this.key = key;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getBaseURL() {
		return baseURL;
	}

	public void setBaseURL(String url) {
		this.baseURL = url;
	}
	
	public Long getStatusId() {
		return statusId;
	}
	
	public void setStatusId(Long statusId) {
		this.statusId = statusId;
	}
	
	public String getStatus() {
		return status;
	}
	
	public void setStatus(String status) {
		this.status = status;
	}
	
	public Date getLastSuccessfulSynchTimestamp() {
		return lastSuccessfulSynchTimestamp;
	}
	
	public void setLastSuccessfulSynchTimestamp(Date lastSuccessfulSynchTimestamp) {
		this.lastSuccessfulSynchTimestamp = lastSuccessfulSynchTimestamp;
	}

	/*
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		return key.hashCode() + 41;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;

		if (!(obj instanceof UiComponent))
			return false;

		/* Must have the same keys */
		UiComponent other = (UiComponent) obj;
		return key.equals(other.key);
	}
}
